from .vision_coder import get_vision_coder
from .schemas import VisionRequest,VisionResult
# runners/vision_runner.py — wraps VisionCoder
class VisionRunner:
    request_type = VisionRequest
    result_type = VisionResult

    def __init__(self, model_key: str):
        self.model_key = model_key
        self.vision = get_vision_coder()

    async def run(self, req):
        text = await asyncio.to_thread(
            self.vision.analyze_image,
            image_path=req.image_path, prompt=req.prompt,
            max_new_tokens=req.max_new_tokens,
        )
        return VisionResult(
            request_id=req.request_id, model_key=req.model_key, text=text,
        )



from imports import *
port = 7000

for module_key,values in MODEL_REGISTRY.items():
    if values.framework == "llama_cpp":
        print(module_key)
        port+=1
        input(values.port)
        
input(sorted(MODEL_REGISTRY.keys()))#asyncio.run(summarize_text('hihihi')))
edit_service  6008_abstractendeavors_qwen25_coder_15b
sudo cp /etc/systemd/system/6008_abstractendeavors_qwen25_coder_15b.service /etc/systemd/system/7000_abstractendeavors_qwen25_coder_15b.service
sudo systemctl stop  6008_abstractendeavors_qwen25_coder_15b
sudo systemctl disable 6008_abstractendeavors_qwen25_coder_15b
sudo systemctl enable 7000_abstractendeavors_qwen25_coder_15b
sudo systemctl start 7000_abstractendeavors_qwen25_coder_15b
